/**
 * JASMINe
 * Copyright (C) 2007-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;
import java.util.UUID;

import javax.naming.NamingException;

import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventNotificationSLBRemote;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * A wrapper class that accesses JasmineEvent objects via EJB3.
 */
public class JasmineEventNotificationEJB3Wrapper extends MuleEJB3Wrapper<JasmineEventNotificationSLBRemote> {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(this.getClass());

    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public JasmineEventNotificationEJB3Wrapper() {
        super(true);
    }

    /**
     * Saves each event detail in a JASMINe Event Notification.
     *
     * @param jasmineEventNotification JasmineEventNotification
     */
    public void saveJasmineEventNotification(final JasmineEventNotification jasmineEventNotification) {
        ClassLoader currentClassLoader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(JasmineEventNotificationEJB3Wrapper.class.getClassLoader());

        // CAREFUL: JasmineEventNotificationDispatcher may have set the UUID before!
        if (jasmineEventNotification.getId() == null) {
            jasmineEventNotification.setId(UUID.randomUUID().toString());
        }
        try {
            getBean().saveEvent(jasmineEventNotification);
        } catch (NamingException e) {
            logger.warn("EJBs are not ready ... the message is not persisted");
        } catch (IOException e) {
            logger.warn("EJBs are not ready ... the message is not persisted");
        } finally {
            Thread.currentThread().setContextClassLoader(currentClassLoader);
        }
    }

}
